/***************************************************************************
                          ktabwidget.cpp  -  description
                             -------------------
    begin                : Sam Feb 1 2003
    copyright            : (C) 2003 by Matthias Reif
    email                : matthias.reif@informatik.tu-chemnitz.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "ksingletabwidget.h"

KSingleTabWidget::KSingleTabWidget( QWidget *parent, const char *name ) : QWidget( parent,name )
{
	layout = new QGridLayout( this, 1, 8 );
	layout->setAlignment( Qt::AlignHCenter );
	layout->setSpacing( 10 );
	layout->setMargin( 15 );
	layout->setColStretch( 7, 1 );
	layout->setColSpacing( 1, 10 );
	layout->setColSpacing( 4, 45 );
	layout->setColSpacing( 6, 10 );
}

KSingleTabWidget::~KSingleTabWidget()
{
}


/*!
    \fn KSingleTabWidget::getLayout()
 */
QGridLayout* KSingleTabWidget::getLayout()
{
	return layout;
}
